Learn R Programming

signalHsmm (version 1.3)

benchmark_dat: Benchmark data set for signalHsmm

Description

Lists eukaryotic proteins added to UniProt database release 2015_06 between 1.01.2010 and 1.06.2015 (140 proteins with signal peptide and 280 randomly sampled proteins without signal peptide). All proteins were used in the benchmark test to compare the performance of signalHsmm and other signal peptide predictors.

Usage

benchmark_dat

Arguments

format

a list of SeqFastaAA objects. Slot sig contains the range of signal peptide (if any).

source

http://www.uniprot.org/{UniProt}

Examples

Run this code
summary(benchmark_dat)

Run the code above in your browser using DataLab