Learn R Programming

signalHsmm (version 1.3)

hsmm_pred: hsmm_pred class

Description

A single prediction of signalHsmm.

A stochastic model of signal peptide produced by signalHsmm.

Arguments

Details

Always a named list of five elements
  1. sp_probabilityis a probability of signal peptide presence.
  2. sp_startis a start of potential signal peptide (naively 1 aminoacid).
  3. sp_endis a position of last amino acid of signal peptide.
  4. strucis numeric vector representing predicted structure of input protein.
  5. protis character vector containing input sequence of amino acids.
  6. str_approxhas value bigger than 0 if the predicted signal peptide structure was approximated (usually in case of sequences that have no signal peptides).

Always a named list of five elements

  1. aa_groupencoding of amino acids. Seeaaaggregationfor an example.
  2. piparprobabilities of initial state in Markov Model.
  3. tpmparmatrix of transition probabilities between states.
  4. odmatrix of response probabilities. Eg. od[1,2] is a probability of signal 2 in state 1.
  5. overall_probs_logprobabilities of amino acids in mature protein.
  6. paramsmatrix of probability distribution for duration. Eg. params[10,2] is probability of duration of time 10 in state 2.

See Also

summary.hsmm_pred plot.hsmm_pred

train_hsmm predict.sighsmm_model