Learn R Programming

signalHsmm (version 1.3)

pred2df: Convert list of signalHsmm predictions

Description

Converts objects of class hsmm_pred_list to data frame.

Usage

pred2df(object)

Arguments

object
of class hsmm_pred_list.

Value

  • Data frame which columns contain respectively the probability of signal peptide presence as well as the start and the end of predicted signal peptide.