Learn R Programming

signalHsmm (version 1.3)

read_uniprot: Read data from UniProt database

Description

Read data saved in UniProt original flat text format.

Usage

read_uniprot(connection, what = "signal", euk)

Arguments

connection
a connection to UniProt data in text format.
what
NULL or a single character determining which information should be extracted. Currently can have following values: "signal", "transit" or NULL.
euk
logical value if data has an eukaryotic origin.

Value

  • a list of sequences. Each element has a class SeqFastaAA. Attribute sig contains the range (start and end) of signal peptide. Attributes OS and OC represents respectively OS and OC fields in the protein description. Sequence with more than one cleavage site or atypical aminoacids are removed without any notice.