find_nhc: Localize n-, h- and c-region in signal peptide
Description
Finds borders between distinct regions constituting signal peptides using a heuristic
algorithm.
Usage
find_nhc(protein, signal = NULL)
Arguments
protein
a vector of amino acids or object of class
SeqFastaAA.
signal
range of signal peptide. If NULL, the attribute sig
of protein will be used.
Value
a vector of length 4 containing positions of:
start of n-region,
start of h-region,
start of c-region,
cleavage site.
References
Henrik Nielsen, Anders Krogh (1998). Prediction of signal peptides
and signal anchors by a hidden Markov model. Proc. Sixth Int. Conf. on
Intelligent Systems for Molecular Biology.