signalHsmm.A stochastic model of signal peptide produced by signalHsmm.
sp_probabilityis a probability of signal peptide presence.sp_startis a start of potential signal peptide (naively 1 aminoacid).sp_endis a position of last amino acid of signal peptide.strucis numeric vector representing predicted structure of input
protein.protis character vector containing input sequence of amino acids.str_approxhas value bigger than 0 if the predicted signal peptide
structure was approximated (usually in case of sequences that have no signal peptides).Always a named list of five elements
aa_groupencoding of amino acids. Seeaaaggregationfor an example.piparprobabilities of initial state in Markov Model.tpmparmatrix of transition probabilities between states.odmatrix of response probabilities. Eg. od[1,2] is a probability
of signal 2 in state 1.overall_probs_logprobabilities of amino acids in mature protein.paramsmatrix of probability distribution for duration. Eg. params[10,2]
is probability of duration of time 10 in state 2.summary.hsmm_pred plot.hsmm_pred